@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,6 @@
 #ifndef HTMLGEN_H
 #define HTMLGEN_H
 
-#include "qtbc.h"
 #include "outputgen.h"
 #include "ftextstream.h"
 
@@ -49,6 +48,8 @@ class HtmlCodeGenerator : public CodeOutputInterface
     void endFontClass();
     void writeCodeAnchor(const char *anchor);
     void linkableSymbol(int,const char *,Definition *,Definition *);
+    void setCurrentDoc(Definition *,const char *,bool) {}
+    void addWord(const char *,bool) {}
 
   private:
     void docify(const char *str);
@@ -72,6 +73,7 @@ class HtmlGenerator : public OutputGenerator
     static void writeSearchInfo(FTextStream &t,const QCString &relPath);
     static void writeSearchData(const char *dir);
     static void writeSearchPage();
+    static void writeExternalSearchPage();
     static QCString writeLogoAsString(const char *path);
     static QCString writeSplitBarAsString(const char *name,const char *relpath);
    
@@ -112,6 +114,8 @@ class HtmlGenerator : public OutputGenerator
     { m_codeGen.linkableSymbol(line,symName,symDef,context); }
     // ---------------------------
 
+    void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile);
+    void addWord(const char *word,bool hiPriority);
     void writeDoc(DocNode *,Definition *,MemberDef *);
 
     void startFile(const char *name,const char *manName,const char *title);
@@ -262,16 +266,21 @@ class HtmlGenerator : public OutputGenerator
     void endContents();
     void writeNonBreakableSpace(int);
     
-    void startDescTable()
-    { t << "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl; }
+    void startDescTable(const char *title)
+    //{ t << "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl; }
+    { t << "<table class=\"fieldtable\">" << endl
+        << "<tr><th colspan=\"2\">" << title << "</th></tr>";
+    }
     void endDescTable()
     { t << "</table>" << endl; }
     void startDescTableTitle()
-    { t << "<tr><td valign=\"top\"><em>"; }
+    //{ t << "<tr><td valign=\"top\"><em>"; }
+    { t << "<tr><td class=\"fieldname\"><em>"; }
     void endDescTableTitle()
     { t << "</em>&nbsp;</td>"; }
     void startDescTableData()
-    { t << "<td>" << endl; }
+    //{ t << "<td>" << endl; }
+    { t << "<td class=\"fielddoc\">" << endl; }
     void endDescTableData()
     { t << "</td></tr>" << endl; }
     
